0.0.1 (2020-07-06)
==================

Features
--------

- Created initial release with test suite ported from ``python-swiftclient`` to ensure full API compatibility.  `#1 <https://github.com/canonical/swiftmock/issues/1>`_
